# Copyright Vahid Zehtab (vahid@zehtab.me) 2023
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from lightning.pytorch.cli import LightningCLI
import lightning
from importlib.metadata import version


def main():
    print(f"lightning_toolbox version {version('lightning-toolbox')} invoked")
    LightningCLI(
        lightning.LightningModule,
        lightning.LightningDataModule,
        subclass_mode_model=True,
        subclass_mode_data=True,
        auto_configure_optimizers=False,
    )


if __name__ == "__main__":
    main()
